@@ -1,5 +1,10 @@
+from __future__ import annotations
 import types
+import typing
 from threading import Lock
+from typing import TYPE_CHECKING
+if TYPE_CHECKING:
+    from pyhtmlgui.lib.observableList import ObservableList
 from .pyhtmlview import PyHtmlView
 
 
@@ -10,8 +15,16 @@ class ObservableListView(PyHtmlView):
         {% endfor %}
     '''
 
-    def __init__(self, subject, parent, item_class, wrapper_element=PyHtmlView.WRAPPER_ELEMENT,
-                 sort_key=None, sort_reverse=False, filter_function=None, **kwargs):
+    def __init__(self,
+                 subject        : ObservableList,
+                 parent         : PyHtmlView,
+                 item_class     : type[PyHtmlView],
+                 wrapper_element: str             = PyHtmlView.WRAPPER_ELEMENT,
+                 sort_key       : typing.Callable = None,
+                 sort_reverse   : bool            = False,
+                 filter_function: typing.Callable = None,
+                 **kwargs):
+
         self._item_class = item_class
         self.WRAPPER_ELEMENT = wrapper_element
         self._kwargs = kwargs
@@ -24,14 +37,14 @@ class ObservableListView(PyHtmlView):
             self.filter_function = lambda x: False
         super().__init__(subject, parent)
 
-    def get_items(self):
+    def get_items(self) -> list:
         data = [w for w in self._wrapped_data if self.filter_function(w) is False]
         if self.sort_key is None:
             return data
         else:
             return sorted(data, key=self.sort_key, reverse=self.sort_reverse)
 
-    def set_visible(self, visible):
+    def set_visible(self, visible: bool) -> None:
         if self.is_visible == visible:  # not changed
             return
         self._wrapped_data_lock.acquire()
@@ -44,7 +57,7 @@ class ObservableListView(PyHtmlView):
 
     def _create_item(self, item):
         obj = self._item_class(item, self, **self._kwargs)
-        obj.loop_index = types.MethodType(lambda x: x.parent._loop_index(x), obj)
+        obj.loop_index = types.MethodType(lambda x: x.parent.get_element_index(x), obj)
         obj.loop_index_used = False
         return obj
 
@@ -58,9 +71,10 @@ class ObservableListView(PyHtmlView):
                 if self.filter_function(obj) is False:
                     if self.insert_element(kwargs["index"], obj) is False:
                         self._wrapped_data.remove(obj)
-                    else:
-                        [item.update() for item in self._wrapped_data[kwargs["index"] + 1:] if
-                         item.loop_index_used is True]  # update items that use the loop index
+                    else:  # update items that use the loop index
+                        for item in self._wrapped_data[kwargs["index"] + 1:]:
+                            if item.loop_index_used is True:
+                                item.update()
 
             if kwargs["action"] == "setitem":
                 self._wrapped_data[kwargs["index"]].delete()  # unrender
@@ -94,6 +108,6 @@ class ObservableListView(PyHtmlView):
         finally:
             self._wrapped_data_lock.release()
 
-    def _loop_index(self, element):
+    def get_element_index(self, element):
         element.loop_index_used = True
         return self._wrapped_data.index(element)
